ConnectedApp class

Implementers
Annotations
  • @sealed

Constructors

ConnectedApp(ServiceManager<VmService>? serviceManager)

Properties

connectedAppInitialized → bool
no setter
flutterVersionNow → FlutterVersion?
no setter
hashCode → int
The hash code for this object.
no setterinherited
initialized ↔ Completer<bool>
getter/setter pair
isDartCliApp → Future<bool>
no setter
isDartCliAppNow → bool
no setter
isDartWebApp → Future<bool>
no setter
isDartWebAppNow → bool?
no setter
isDebugFlutterAppNow → bool
no setter
isDebuggableWebApp → bool
Returns true is the connected application's VM has the name dwdsChromeDebugProxyDeviceName, indicating that DWDS has an active Chrome debugger connection with support for expression evaluation, object inspection, and setting breakpoints.
no setter
isFlutterApp → Future<bool>
no setter
isFlutterAppNow → bool?
no setter
isFlutterNativeAppNow → bool
no setter
isFlutterWebAppNow → bool
no setter
isProfileBuild → Future<bool>
no setter
isProfileBuildNow → bool?
no setter
isRunningOnDartVM → bool?
no setter
operatingSystem → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceManager → ServiceManager<VmService>?
final

Methods

initializeValues({void onComplete()?}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited