ConnectedState class

Constructors

ConnectedState(bool connected, {bool userInitiatedConnectionState = false})
const

Properties

connected → bool
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInitiatedConnectionState → bool
Whether this ConnectedState was manually initiated by the user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override