DeveloperServiceEvent class abstract

Events received over the VM Service from one the running developer services (DDS, VM Service, etc.).

This is a class instead of an enum so that the event name values can be used in constant expressions.

Constructors

DeveloperServiceEvent()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited