EvalOnDartLibrary class

Inheritance
Mixed-in types
Annotations
  • @sealed

Constructors

EvalOnDartLibrary(String libraryName, VmService service, {required ServiceManager<VmService> serviceManager, ValueListenable<IsolateRef?>? isolate, bool disableBreakpoints = true, bool oneRequestAtATime = false, bool logExceptions = true})

Properties

allPendingRequestsDone ↔ Completer<void>?
getter/setter pair
disableBreakpoints → bool
Whether to disable breakpoints triggered while evaluating expressions.
final
disposed → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isolate → Isolate?
no setter
isolateRef → IsolateRef?
no setter
libraryName → String
final
listenables → List<Listenable>
no setterinherited
listeners → List<void Function()>
Not using VoidCallback because of https://github.com/dart-lang/mockito/issues/579
no setterinherited
logExceptions → bool
Whether to log exceptions to stdout on failed evaluations.
final
oneRequestAtATime → bool
Whether to wait for one request to complete before issuing another request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → VmService
final
serviceManager → ServiceManager<VmService>
The service manager to use for this instance of EvalOnDartLibrary.
final

Methods

addAutoDisposeListener(Listenable? listenable, [VoidCallback? listener, String? id]) → void
Add a listener to a Listenable object that is automatically removed when cancel is called.
inherited
addRequest<T>(Disposable? isAlive, Future<T?> request()) → Future<T?>
Public so that other related classes such as InspectorService can ensure their requests are in a consistent order with existing requests.
asyncEval(String expression, {required Disposable? isAlive, Map<String, String>? scope}) → Future<InstanceRef?>
A safeEval variant that can use await.
autoDisposeFocusNode(FocusNode? node) → void
Track a focus node that will be automatically disposed on dispose.
inherited
autoDisposeStreamSubscription(StreamSubscription subscription) → void
Track a stream subscription to be automatically cancelled on dispose.
inherited
callOnceWhenReady<T>({required VoidCallback callback, required ValueListenable<T> trigger, required bool readyWhen(T triggerValue)}) → void
Runs callback when trigger's value satisfies the readyWhen function.
inherited
cancelFocusNodes() → void
Cancel all focus nodes added.
inherited
cancelListener(VoidCallback? listener) → void
Cancels a single listener, if present.
inherited
cancelListeners({List<String> excludeIds = const <String>[]}) → void
Cancel all listeners added.
inherited
cancelStreamSubscriptions() → void
Cancel all stream subscriptions added.
inherited
dispose() → void
override
eval(String expression, {required Disposable? isAlive, Map<String, String>? scope, bool shouldLogError = true}) → Future<InstanceRef?>
evalInstance(String expression, {required Disposable? isAlive, Map<String, String>? scope}) → Future<Instance>
Eval an expression and immediately obtain its Instance.
getClass(ClassRef instance, Disposable isAlive) → Future<Class?>
getFunc(FuncRef instance, Disposable isAlive) → Future<Func?>
getHashCode(InstanceRef instance, {required Disposable? isAlive}) → Future<int>
getInstance(FutureOr<InstanceRef> instanceRefFuture, Disposable? isAlive) → Future<Instance?>
getObjHelper<T extends Obj>(ObjRef instance, Disposable? isAlive, {int? offset, int? count}) → Future<T?>
init() → void
inherited
invoke(InstanceRef instanceRef, String name, List<String> argRefs, {required Disposable? isAlive, bool shouldLogError = true}) → Future<InstanceRef?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
safeEval(String expression, {required Disposable? isAlive, Map<String, String>? scope}) → Future<InstanceRef>
An eval that throws when a Sentinel/error occurs or if isAlive was disposed while the request was pending.
safeGetClass(ClassRef instance, Disposable isAlive) → Future<Class>
safeGetInstance(FutureOr<InstanceRef> instanceRefFuture, Disposable? isAlive) → Future<Instance>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited