FlutterEvent class abstract

Events received over the VM Service from the Flutter framework.

This is a class instead of an enum so that the event name values can be used in constant expressions.

Constructors

FlutterEvent()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

error → const String
firstFrame → const String
frame → const String
frameworkInitialization → const String
imageSizesForFrame → const String
print → const String
rebuiltWidgets → const String
serviceExtensionStateChanged → const String