FlutterVersion class final

Implemented types

Constructors

FlutterVersion.parse(Map<String, dynamic> json)
factory
FlutterVersion.unknown()
factory

Properties

channel → String?
final
dartSdkVersion → SemanticVersion?
final
engineRevision → String?
final
frameworkCommitDate → String?
final
frameworkRevision → String?
final
hashCode → int
The hash code for this object.
no setteroverride
isPreRelease → bool
no setterinherited
major ↔ int
getter/setter pairinherited
minor ↔ int
getter/setter pairinherited
patch ↔ int
getter/setter pairinherited
preReleaseMajor ↔ int?
getter/setter pairinherited
preReleaseMinor ↔ int?
getter/setter pairinherited
repositoryUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → bool
no setter
version → String?
final

Methods

compareTo(SemanticVersion other) → int
Compares this object to another object.
inherited
downgrade({bool downgradeMajor = false, bool downgradeMinor = false, bool downgradePatch = false}) → SemanticVersion
Returns a new SemanticVersion that is downgraded from this.
inherited
isSupported({required SemanticVersion minSupportedVersion}) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(SemanticVersion other) → bool
inherited
operator <=(SemanticVersion other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
override
operator >(SemanticVersion other) → bool
inherited
operator >=(SemanticVersion other) → bool
inherited

Static Methods

identifyChannel(String versionStr, {String? channelStr}) → FlutterChannel?
Identifies the Flutter channel from a version string.