FutureFailedException class final

Implemented types

Constructors

FutureFailedException(String expression, InstanceRef errorRef, InstanceRef stacktraceRef)

Properties

errorRef → InstanceRef
final
expression → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stacktraceRef → InstanceRef
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited