IsolateState class

Annotations
  • @sealed

Constructors

IsolateState(IsolateRef isolateRef)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isolate → Future<Isolate?>
Returns null if only this instance of IsolateState is disposed.
no setter
isolateNow → Isolate?
no setter
isolateRef → IsolateRef
final
isPaused → ValueListenable<bool>
no setter
rootInfo ↔ RootInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
handleDebugEvent(String? kind) → void
handleIsolateLoad(Isolate isolate) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
waitForIsolateLoad() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited