OfflineConnectedApp class final

Inheritance

Constructors

OfflineConnectedApp({bool? isFlutterAppNow, bool? isProfileBuildNow, bool? isDartWebAppNow, bool? isRunningOnDartVM, String operatingSystem = ConnectedApp.unknownOS})
OfflineConnectedApp.parse(Map<String, Object?>? json)
factory

Properties

connectedAppInitialized → bool
no setterinherited
flutterVersionNow → FlutterVersion?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
initialized ↔ Completer<bool>
getter/setter pairinherited
isDartCliApp → Future<bool>
no setterinherited
isDartCliAppNow → bool
no setterinherited
isDartWebApp → Future<bool>
no setterinherited
isDartWebAppNow → bool?
final
isDebugFlutterAppNow → bool
no setterinherited
isDebuggableWebApp → bool
Returns true is the connected application's VM has the name dwdsChromeDebugProxyDeviceName, indicating that DWDS has an active Chrome debugger connection with support for expression evaluation, object inspection, and setting breakpoints.
no setterinherited
isFlutterApp → Future<bool>
no setterinherited
isFlutterAppNow → bool?
final
isFlutterNativeAppNow → bool
no setterinherited
isFlutterWebAppNow → bool
no setterinherited
isProfileBuild → Future<bool>
no setterinherited
isProfileBuildNow → bool?
final
isRunningOnDartVM → bool?
final
operatingSystem → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceManager → ServiceManager<VmService>?
finalinherited

Methods

initializeValues({void onComplete()?}) → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited