ServiceManager<T extends VmService> class

Annotations
  • @sealed

Constructors

ServiceManager()

Properties

connectedApp ↔ ConnectedApp?
getter/setter pair
connectedAppInitialized → bool
no setter
connectedState → ValueListenable<ConnectedState>
no setter
deviceBusy → ValueListenable<bool>
Whether the device is currently busy - performing a long-lived, blocking operation.
no setter
flutterVersion → Future<Response>
no setter
hasConnection → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isMainIsolatePaused → bool
Proxy to state inside the isolateManager, for code conciseness.
no setter
isolateManager → IsolateManager
final
isServiceAvailable → bool
no setter
onServiceAvailable → Future<VmService>
no setter
registeredMethodsForService → Map<String, String>
Mapping of service name to service method.
no setter
resolvedUriManager → ResolvedUriManager
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkVersion ↔ String?
getter/setter pair
service ↔ T?
getter/setter pair
serviceCapabilities → Future<VmServiceCapabilities>
no setter
serviceExtensionManager → ServiceExtensionManager
no setter
serviceUri ↔ String?
The URI of the most recent VM service connection service.
getter/setter pair
vm ↔ VM?
getter/setter pair

Methods

callLifecycleCallbacks(ServiceManagerLifecycle lifecycle, T? service) → FutureOr<void>
callService(String name, {String? isolateId, Map<String, dynamic>? args}) → Future<Response>
Call a service that is registered by exactly one client.
callServiceExtensionOnMainIsolate(String method, {Map<String, dynamic>? args}) → Future<Response>
callServiceOnMainIsolate(String name) → Future<Response>
connectedAppPackageRoot(DTDManager dtdManager) → Future<Uri?>
Returns the package root URI for the connected app.
libraryUriAvailable(String uri) → Future<bool>
libraryUriAvailableNow(String? uri) → bool
mainIsolateRootLibraryUriAsString() → Future<String?>
Returns a file URI String for the root library of the connected app's main isolate.
manuallyDisconnect() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performHotReload() → Future<void>
This can throw an RPCError.
performHotRestart() → Future<void>
This can throw an RPCError.
registeredServiceListenable(String name) → ValueListenable<bool>
registerLifecycleCallback(ServiceManagerLifecycle lifecycle, ServiceManagerCallback<T> callback) → void
Registers a callback that will be called at a particular phase in the lifecycle of opening or closing a VmService connection.
registerOverride(ServiceManagerOverride override, ServiceManagerCallback<T> callback) → void
Registers a callback that will be called in place of the default ServiceManager logic for a codeblock defined by a ServiceManagerOverride.
rootInfoNow() → RootInfo
rootPackageDirectoryForMainIsolate(DTDManager dtdManager) → Future<String?>
Returns the root package directory for the main isolate.
runDeviceBusyTask<V>(Future<V> task) → Future<V>
Set the device as busy during the duration of the given async task.
setDeviceBusy(bool isBusy) → void
Set whether the device is currently busy - performing a long-lived, blocking operation.
toString() → String
A string representation of this object.
inherited
tryToDetectMainRootInfo() → Future<RootInfo?>
vmServiceClosed({ConnectedState connectionState = const ConnectedState(false)}) → FutureOr<void>
Shuts down the service manager's current vm service connection.
vmServiceOpened(T service, {required Future<void> onClosed}) → Future<void>
Initializes the service manager for a new vm service connection service.
waitUntilNotPaused() → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited