ServiceExtension<T> class

Implementers

Constructors

ServiceExtension({required String extension, required List<T> values, bool shouldCallOnAllIsolates = false})

Properties

extension → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldCallOnAllIsolates → bool
final
values → List<T>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited