ToggleableServiceExtension<T extends Object> class

Inheritance

Constructors

ToggleableServiceExtension({required String extension, required T enabledValue, required T disabledValue, bool shouldCallOnAllIsolates = false, bool inverted = false})

Properties

disabledValue → T
no setter
enabledValue → T
no setter
extension → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inverted → bool
Whether this service extension will be inverted where it is exposed in DevTools.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldCallOnAllIsolates → bool
finalinherited
values → List<T>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

disabledValueIndex → const int
enabledValueIndex → const int