ButtonGroupItemData class final

Constructors

ButtonGroupItemData({String? label, IconData? icon, String? iconAsset, double? iconSize, String? tooltip, VoidCallback? onPressed, bool autofocus = false})
const

Properties

autofocus → bool
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
final
iconAsset → String?
final
iconSize → double?
final
label → String?
final
onPressed → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited