IdeTheme class final

IDE-supplied theming.

Constructors

IdeTheme({Color? backgroundColor, Color? foregroundColor, EmbedMode embedMode = EmbedMode.none, bool? isDarkMode})

Properties

backgroundColor → Color?
final
embedded → bool
no setter
embedMode → EmbedMode
final
foregroundColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
ideSpecifiedTheme → bool
Whether the IDE specified the DevTools color theme.
no setter
isDarkMode → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited