RoundedCornerOptions class

Constructors

RoundedCornerOptions({bool showTopLeft = true, bool showTopRight = true, bool showBottomLeft = true, bool showBottomRight = true})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBottomLeft → bool
final
showBottomRight → bool
final
showTopLeft → bool
final
showTopRight → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const RoundedCornerOptions
Static constant instance with all borders hidden