RoundedOutlinedBorder class final

Wraps child in a rounded border with default styling.

This border can optionally be made non-uniform by setting any of showTopLeft, showTopRight, showBottomLeft, or showBottomRight to false.

If clip is true, the child will be wrapped in a ClipRRect to ensure the rounded corner of the border is drawn as expected. This should not be necessary in most cases.

Inheritance

Constructors

RoundedOutlinedBorder({Key? key, bool showTopLeft = true, bool showTopRight = true, bool showBottomLeft = true, bool showBottomRight = true, bool clip = false, required Widget? child})
const
RoundedOutlinedBorder.onlyBottom({required Widget? child, bool clip = false})
factory
RoundedOutlinedBorder.onlyTop({required Widget? child, bool clip = false})
factory

Properties

child → Widget?
final
clip → bool
Whether we should clip child.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBottomLeft → bool
final
showBottomRight → bool
final
showTopLeft → bool
final
showTopRight → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited