ScrollControllerAutoScroll extension

An extension on ScrollController to facilitate having the scrolling widget auto scroll to the bottom on new content.

on

Properties

atScrollBottom → bool

Available on ScrollController, provided by the ScrollControllerAutoScroll extension

Return whether the view is currently scrolled to the bottom.
no setter

Methods

autoScrollToBottom({bool jump = false}) → Future<void>

Available on ScrollController, provided by the ScrollControllerAutoScroll extension

Scroll the content to the bottom.