EnumIndexOrdering<T extends Enum> mixin

Superclass constraints
Implemented types
Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(T other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(T other) → bool
operator <=(T other) → bool
operator ==(Object other) → bool
The equality operator.
inherited
operator >(T other) → bool
operator >=(T other) → bool